@@ -13,6 +13,7 @@ require 'tempfile'
 require 'tmpdir'
 require 'mcollective/monkey_patches'
 require 'mcollective/cache'
+require 'mcollective/exceptions'
 
 # == The Marionette Collective
 #
@@ -24,20 +25,6 @@ require 'mcollective/cache'
 # For an overview of the idea behind this and what it enables please see:
 #   http://www.devco.net/archives/2009/10/18/middleware_for_systems_administration.php
 module MCollective
-  # Exceptions for the RPC system
-  class DDLValidationError<RuntimeError;end
-  class ValidatorError<RuntimeError; end
-  class MsgDoesNotMatchRequestID < RuntimeError; end
-  class MsgTTLExpired<RuntimeError;end
-  class NotTargettedAtUs<RuntimeError;end
-  class RPCError<StandardError;end
-  class SecurityValidationFailed<RuntimeError;end
-
-  class InvalidRPCData<RPCError;end
-  class MissingRPCData<RPCError;end
-  class RPCAborted<RPCError;end
-  class UnknownRPCAction<RPCError;end
-  class UnknownRPCError<RPCError;end
 
   autoload :Agent, "mcollective/agent"
   autoload :Agents, "mcollective/agents"
@@ -72,7 +59,7 @@ module MCollective
 
   MCollective::Vendor.load_vendored
 
-  VERSION="2.4.0"
+  VERSION="2.5.3"
 
   def self.version
     VERSION
